pub struct Drives {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl Drives
impl Drives
Sourcepub async fn list(
&self,
page_size: i64,
page_token: &str,
q: &str,
use_domain_admin_access: bool,
) -> Result<Response<Vec<Drive>>, ClientError>
pub async fn list( &self, page_size: i64, page_token: &str, q: &str, use_domain_admin_access: bool, ) -> Result<Response<Vec<Drive>>, ClientError>
This function performs a GET to the /drives endpoint.
Lists the user’s shared drives.
Parameters:
page_size: i64– A map of maximum import sizes by MIME type, in bytes.page_token: &str– A link to this theme’s background image.q: &str– A link to this theme’s background image.use_domain_admin_access: bool– Issue the request as a domain administrator; if set to true, then all shared drives of the domain in which the requester is an administrator are returned.
Sourcepub async fn list_all(
&self,
q: &str,
use_domain_admin_access: bool,
) -> Result<Response<Vec<Drive>>, ClientError>
pub async fn list_all( &self, q: &str, use_domain_admin_access: bool, ) -> Result<Response<Vec<Drive>>, ClientError>
This function performs a GET to the /drives endpoint.
As opposed to list, this function returns all the pages of the request at once.
Lists the user’s shared drives.
Sourcepub async fn create(
&self,
request_id: &str,
body: &Drive,
) -> Result<Response<Drive>, ClientError>
pub async fn create( &self, request_id: &str, body: &Drive, ) -> Result<Response<Drive>, ClientError>
This function performs a POST to the /drives endpoint.
Creates a new shared drive.
Parameters:
request_id: &str– An ID, such as a random UUID, which uniquely identifies this user’s request for idempotent creation of a shared drive. A repeated request by the same user and with the same request ID will avoid creating duplicates by attempting to create the same shared drive. If the shared drive already exists a 409 error will be returned.
Sourcepub async fn get(
&self,
drive_id: &str,
use_domain_admin_access: bool,
) -> Result<Response<Drive>, ClientError>
pub async fn get( &self, drive_id: &str, use_domain_admin_access: bool, ) -> Result<Response<Drive>, ClientError>
This function performs a GET to the /drives/{driveId} endpoint.
Gets a shared drive’s metadata by ID.
Parameters:
drive_id: &str– A link to this theme’s background image.use_domain_admin_access: bool– Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the shared drive belongs.
Sourcepub async fn delete(&self, drive_id: &str) -> Result<Response<()>, ClientError>
pub async fn delete(&self, drive_id: &str) -> Result<Response<()>, ClientError>
This function performs a DELETE to the /drives/{driveId} endpoint.
Permanently deletes a shared drive for which the user is an organizer. The shared drive cannot contain any untrashed items.
Parameters:
drive_id: &str– A link to this theme’s background image.
Sourcepub async fn update(
&self,
drive_id: &str,
use_domain_admin_access: bool,
body: &Drive,
) -> Result<Response<Drive>, ClientError>
pub async fn update( &self, drive_id: &str, use_domain_admin_access: bool, body: &Drive, ) -> Result<Response<Drive>, ClientError>
This function performs a PATCH to the /drives/{driveId} endpoint.
Updates the metadate for a shared drive.
Parameters:
drive_id: &str– A link to this theme’s background image.use_domain_admin_access: bool– Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the shared drive belongs.