pub struct Replies {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl Replies
impl Replies
Sourcepub async fn list(
&self,
file_id: &str,
comment_id: &str,
include_deleted: bool,
page_size: i64,
page_token: &str,
) -> Result<Response<Vec<Reply>>, ClientError>
pub async fn list( &self, file_id: &str, comment_id: &str, include_deleted: bool, page_size: i64, page_token: &str, ) -> Result<Response<Vec<Reply>>, ClientError>
This function performs a GET to the /files/{fileId}/comments/{commentId}/replies endpoint.
Lists a comment’s replies.
Parameters:
file_id: &str– A link to this theme’s background image.comment_id: &str– A link to this theme’s background image.include_deleted: bool– Whether to include deleted replies. Deleted replies will not include their original content.page_size: i64– A map of maximum import sizes by MIME type, in bytes.page_token: &str– The token for continuing a previous list request on the next page. This should be set to the value of ‘nextPageToken’ from the previous response.
Sourcepub async fn list_all(
&self,
file_id: &str,
comment_id: &str,
include_deleted: bool,
) -> Result<Response<Vec<Reply>>, ClientError>
pub async fn list_all( &self, file_id: &str, comment_id: &str, include_deleted: bool, ) -> Result<Response<Vec<Reply>>, ClientError>
This function performs a GET to the /files/{fileId}/comments/{commentId}/replies endpoint.
As opposed to list, this function returns all the pages of the request at once.
Lists a comment’s replies.
Sourcepub async fn create(
&self,
file_id: &str,
comment_id: &str,
body: &Reply,
) -> Result<Response<Reply>, ClientError>
pub async fn create( &self, file_id: &str, comment_id: &str, body: &Reply, ) -> Result<Response<Reply>, ClientError>
This function performs a POST to the /files/{fileId}/comments/{commentId}/replies endpoint.
Creates a new reply to a comment.
Parameters:
file_id: &str– A link to this theme’s background image.comment_id: &str– A link to this theme’s background image.
Sourcepub async fn get(
&self,
file_id: &str,
comment_id: &str,
reply_id: &str,
include_deleted: bool,
) -> Result<Response<Reply>, ClientError>
pub async fn get( &self, file_id: &str, comment_id: &str, reply_id: &str, include_deleted: bool, ) -> Result<Response<Reply>, ClientError>
This function performs a GET to the /files/{fileId}/comments/{commentId}/replies/{replyId} endpoint.
Gets a reply by ID.
Parameters:
file_id: &str– A link to this theme’s background image.comment_id: &str– A link to this theme’s background image.reply_id: &str– A link to this theme’s background image.include_deleted: bool– Whether to return deleted replies. Deleted replies will not include their original content.
Sourcepub async fn delete(
&self,
file_id: &str,
comment_id: &str,
reply_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete( &self, file_id: &str, comment_id: &str, reply_id: &str, ) -> Result<Response<()>, ClientError>
This function performs a DELETE to the /files/{fileId}/comments/{commentId}/replies/{replyId} endpoint.
Deletes a reply.
Parameters:
file_id: &str– A link to this theme’s background image.comment_id: &str– A link to this theme’s background image.reply_id: &str– A link to this theme’s background image.
Sourcepub async fn update(
&self,
file_id: &str,
comment_id: &str,
reply_id: &str,
body: &Reply,
) -> Result<Response<Reply>, ClientError>
pub async fn update( &self, file_id: &str, comment_id: &str, reply_id: &str, body: &Reply, ) -> Result<Response<Reply>, ClientError>
This function performs a PATCH to the /files/{fileId}/comments/{commentId}/replies/{replyId} endpoint.
Updates a reply with patch semantics.
Parameters:
file_id: &str– A link to this theme’s background image.comment_id: &str– A link to this theme’s background image.reply_id: &str– A link to this theme’s background image.