pub struct Permission {Show 14 fields
pub allow_file_discovery: Option<bool>,
pub deleted: Option<bool>,
pub display_name: String,
pub domain: String,
pub email_address: String,
pub expiration_time: Option<DateTime<Utc>>,
pub id: String,
pub kind: String,
pub permission_details: Vec<PermissionDetails>,
pub photo_link: String,
pub role: String,
pub team_drive_permission_details: Vec<TeamDrivePermissionDetails>,
pub type_: String,
pub view: String,
}Expand description
A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
Fields
allow_file_discovery: Option<bool>A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
deleted: Option<bool>A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
display_name: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
domain: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
email_address: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
expiration_time: Option<DateTime<Utc>>A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
id: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
kind: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
permission_details: Vec<PermissionDetails>A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
photo_link: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
role: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
team_drive_permission_details: Vec<TeamDrivePermissionDetails>A permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
type_: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.
view: StringA permission for a file. A permission grants a user, group, domain or the world access to a file or a folder hierarchy.